##  Benefits
By using catalog data for application fact sheets, you can:
  * Enhance fact sheet standardization: With catalog data, you can establish better naming standardization across fact sheets and avoid duplication if you used multiple methods to populate your inventory.
  * Increase fact sheet quality: With catalog data, you can enrich required fact sheet fields, helping users to complete fact sheet information with less effort.
  * Maintain up-to-date data: Once application fact sheets are linked to the catalog, the information from the catalog is automatically synced and updated whenever there is a change in the catalog's data. You can select which attributes you want to sync with the catalog.
  * Set relations for best-practice fact sheet modeling: Linking an application to a catalog item can automatically establish relations between fact sheets where the relation is explicit (for example, between SaaS applications and SaaS Hosting IT components). For relations to be set properly, some fact sheets should already exist in the inventory. If they don’t, the catalog creates related fact sheets. This enables you to get the most out of catalog data without impacting the fundamental model.
